<?php
/* This file is part of JFFNMS
 * Copyright (C) <2002-2005> David LIMA <dlima@fr.scc.com> 
 * This program is licensed under the GNU GPL, full terms in the LICENSE file
 */
function poller_snmp_ibm_temperature ($options) {
	extract($options);

	$oid = $poller_parameters;
	if ($ro_community) { //dont do anything if we dont have the community
	    $value2 =  (snmp_get($host_ip,$ro_community,$oid));
	    preg_match('{[+|-](\d+)}',$value2,$value);
	}
	return $value[1];
}
?>
